﻿define([
"dojo/_base/declare",
"dojo/_base/lang",
"dojo/_base/Deferred",

"epi",
"epi/shell/widget/_FocusableMixin",

"epi/cms/widget/_GridWidgetBase",
"epi/cms/core/ContentReference",

"epi/i18n!epi/cms/nls/episerver.samples.module.components.contentlinks"
],

function (declare, lang, Deferred, epi, _FocusableMixin, _GridWidgetBase, ContentReference, res) {

    return declare("epi-samples.component.ContentLinksGrid", [_GridWidgetBase, _FocusableMixin], {
        // summary: This component displays a list of referenced and referencing content for current context item

        res: res,

        displayReferenced: true,

        postMixInProperties: function () {
            // summary:
            //		Called after constructor parameters have been mixed-in; sets default values for parameters that have not been initialized.
            // tags:
            //		protected

            if (!this.store && !this.storeKeyName) {
                this.storeKeyName = "epi.samples.contentlinkdata";
            }

            this.inherited(arguments);
        },

        buildRendering: function () {
            // summary:
            //		Construct the UI for this widget with this.domNode initialized as a dgrid.
            // tags:
            //		protected

            this.inherited(arguments);

            this.grid = new this._gridClass({
                columns: {
                    name: { label: epi.resources.header.name }
                },
                store: this.store,
                selectionMode: "single"
            }, this.domNode);
        },

        startup: function () {
            // summary:
            //		Called on widget startup to setup event handlers and load initial data
            // tags:
            //		protected

            this.inherited(arguments);

            this.fetchData();
        },

        contextChanged: function (context, callerData) {
            // summary:
            //		Overridden to react on any context changes, even if it is requested from this component
            // tags:
            //		protected
            if (context.type !== "epi.cms.contentdata") {
                return;
            }

            this.onContextChanged();
        },

        fetchData: function () {
            // summary:
            //		Updates the grid with the new data.
            // tags:
            //		private

            Deferred.when(this.getCurrentContent(), lang.hitch(this, function (item) {
                var currentReference = this._getReferenceToCurrentPublishedContent(item.contentLink);
                var query = { contentLink: currentReference, getReferenced: this.displayReferenced };
                if (item.currentLanguageBranch) {
                    query.language = item.currentLanguageBranch.languageId;
                }
                this.grid.set("query", query);
            }));
        },

        _getReferenceToCurrentPublishedContent: function (contentLink) {
            // summary:
            //		Creates the reference to the published current content
            // tags:
            //		private
            return new ContentReference(contentLink).createVersionUnspecificReference().toString();
        }
    });
});