﻿using System.ComponentModel.DataAnnotations;
using EPiServer.Core;
using EPiServer.DataAbstraction;
using EPiServer.DataAnnotations;

namespace EPiServer.Samples.Module.Models
{
    /// <summary>
    /// Simple Twitter button block
    /// </summary>
    [ContentType(GUID = "CC38E148-5267-4C61-92B5-B638F4E682A4")]
    public class TwitterButtonBlock : BlockData
    {

        /// <summary>
        /// Gets or sets a value indicating whether button text should be localized.
        /// </summary>
        /// <value>
        ///   <c>true</c> if localize button text; otherwise, <c>false</c>.
        /// </value>
        [Display(Order = 1)]
        public virtual bool LocalizeButtonText { get; set; }

        /// <summary>
        /// Gets or sets the count position parameter.
        /// </summary>
        /// <value>
        /// The count position.
        /// </value>
        [Display(Order = 2)]
        [UIHint(TwitterButtonConstants.CountPositionSelectorHint)]
        public virtual string CountPosition { get; set; }

        /// <summary>
        /// Sets the default values for block properties.
        /// </summary>
        /// <param name="contentType">Type of the content.</param>
        public override void SetDefaultValues(ContentType contentType)
        {
            base.SetDefaultValues(contentType);
            LocalizeButtonText = TwitterButtonConstants.LocalizeButtonTextDefault;
            CountPosition = TwitterButtonConstants.CountPositionSelectionDefault;
        }
    }
}