﻿using System.Globalization;
using System.Text;
using EPiServer.ServiceLocation;
using EPiServer.Web.Routing;

namespace EPiServer.Samples.Module.Models
{
    /// <summary>
    /// View model for Twitter button data, used to get button code for rendenring.
    /// </summary>
    public class TwitterButtonViewModel
    {
        private const string ParametersPlaceholder = "$Parameters$";

        private const string TwitterButtonCodeTemplate = "<a href='https://twitter.com/share' class='twitter-share-button' " + ParametersPlaceholder + @">Tweet</a>
            <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src='https://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}(document,'script','twitter-wjs');</script>";

        private readonly TwitterButtonBlock _buttonBlock;

        /// <summary>
        /// Initializes a new instance of the <see cref="TwitterButtonViewModel"/> class.
        /// </summary>
        /// <param name="twitterButtonBlock">The twitter button block data.</param>
        public TwitterButtonViewModel(TwitterButtonBlock twitterButtonBlock)
        {
            _buttonBlock = twitterButtonBlock;
        }

        /// <summary>
        /// Gets the Twitter button code.
        /// </summary>
        /// <returns></returns>
        public string GetButtonCode()
        {
            var additionalParameters = new StringBuilder();
            if (_buttonBlock.LocalizeButtonText)
            {
                var pageRouteHelper = ServiceLocator.Current.GetInstance<PageRouteHelper>();
                if (pageRouteHelper.Page != null)
                {
                    additionalParameters.AppendFormat(CultureInfo.InvariantCulture, "data-lang='{0}'",
                                                      pageRouteHelper.Page.LanguageBranch);
                }
            }
            if (!string.IsNullOrWhiteSpace(_buttonBlock.CountPosition))
            {
                additionalParameters.AppendFormat(CultureInfo.InvariantCulture, "data-count='{0}'",
                                                      _buttonBlock.CountPosition);
            }
            return TwitterButtonCodeTemplate
                .Replace(ParametersPlaceholder, additionalParameters.ToString());
        }
    }
}