﻿using System;
using System.ComponentModel;
using System.Web.UI;
using System.Web.UI.WebControls;
using EPiServer.DynamicContent;

namespace EPiServer.Samples.Module.PlugIns
{
    /// <summary>
    /// Web control that is available as dynamic content
    /// </summary>
    [DefaultProperty("Text")]
    [ToolboxData("<{0}:DynamicContentAdaptedCustomControl runat=server></{0}:DynamicContentAdaptedCustomControl>")]
    [DynamicContentPlugIn]
    public class DynamicContentAdaptedCustomControl : WebControl
    {
        /// <summary>
        /// Gets or sets the text to render.
        /// </summary>
        /// <value>
        /// The text.
        /// </value>
        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("")]
        [Localizable(true)]
        public string Text
        {
            get
            {
                var text = (String)ViewState["Text"];
                return (text ?? String.Empty);
            }

            set
            {
                ViewState["Text"] = value;
            }
        }

        /// <summary>
        /// Renders the contents.
        /// </summary>
        /// <param name="output">The output.</param>
        protected override void RenderContents(HtmlTextWriter output)
        {
            output.Write(Text);
        }
    }
}
