﻿using System;
using System.Globalization;
using EPiServer.Core;

namespace EPiServer.Samples.Module.Rest.Models
{
    /// <summary>
    /// Content link view model
    /// </summary>
    [Serializable]
    public class ContentLinkModel
    {
        /// <summary>
        /// Gets or sets the ID for this link item.
        /// </summary>
        /// <value>
        /// The ID.
        /// </value>
        public string Id { get; set; }

        /// <summary>
        /// Gets or sets the soft link ID.
        /// </summary>
        /// <value>
        /// The id.
        /// </value>
        public int SoftLinkId { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this content is referenced or referencing.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this content is referenced; otherwise, <c>false</c>.
        /// </value>
        public bool IsReferenced { get; set; }

        /// <summary>
        /// Gets or sets the content link.
        /// </summary>
        /// <value>
        /// The content link.
        /// </value>
        public ContentReference ContentLink { get; set; }

        /// <summary>
        /// Gets or sets the content language.
        /// </summary>
        /// <value>
        /// The language.
        /// </value>
        public CultureInfo Language { get; set; }

        /// <summary>
        /// Gets or sets the type of the content.
        /// </summary>
        /// <value>
        /// The type of the content.
        /// </value>
        public string ContentType { get; set; }

        /// <summary>
        /// Gets or sets the content name.
        /// </summary>
        /// <value>
        /// The content name.
        /// </value>
        public string Name { get; set; }

        /// <summary>
        /// Gets or sets the external link URL.
        /// </summary>
        /// <value>
        /// The URL.
        /// </value>
        public string ExternalUrl { get; set; }

        /// <summary>
        /// The URI identifying the content item.
        /// </summary>
        public Uri Uri { get; set; }
    }
}